@@ -6,8 +6,8 @@ from otsvm import *
 
 # instantiate a kernel=Gaussian with sigma = 2
 kernel = SigmoidKernel()
-x = NumericalPoint(2, 2)
-y = NumericalPoint(2, 1)
+x = Point(2, 2)
+y = Point(2, 1)
 
 print(" kernel ([2 2],[1 1]) = %.3e " % kernel(x, y))
 print(" dkernel/dx_i([2 2],[1 1]) = [ %.3e , %.3e ] " % (kernel.partialGradient(x, y)[0], kernel.partialGradient(x, y)[1]))
